@@ -50,6 +50,10 @@ MAX_COLUMN_WIDTHS = {
 }
 
 
+class ClusterAccessUnsupported(Exception):
+    pass
+
+
 def global_options(fn):
     """Attaches hidden '-n/--namespace' and '--context' options to the command that updates the namespace on the
        Environment object in the context."""
@@ -112,6 +116,9 @@ def fix_url(url):
 @click.pass_context
 def completion(ctx, env: Environment, kubectl_arg):
     """Output shell completion code for the specified shell"""
+    if not env.kubectl.exists():
+        raise Exception("kubectl not found, run any other command to download")
+
     cmdline = ["completion"]
     cmdline.extend(kubectl_arg)
     stdout = env.kubectl.run(cmdline, stdout=subprocess.PIPE).stdout.decode("utf-8")
@@ -269,13 +276,16 @@ def do_list_clusters(config):
     rows = []
     for cluster in data["items"]:
         status = cluster.get("status", {})
-        version = status.get("current_version", "")[:7]
-        if status.get("next_version") and status.get("current_version") != status.get("next_version"):
-            version += " (updating)"
-        cluster["version"] = version
+
+        next_version = status.get("next_version")
+        if next_version and next_version != status.get("current_version"):
+            cluster["status"] = "updating"
+        else:
+            cluster["status"] = "ready"
+
         rows.append(cluster)
     rows.sort(key=lambda c: (c["alias"], c["id"]))
-    print_table("id alias environment channel version".split(), rows)
+    print_table("id alias environment channel status".split(), rows)
     return rows
 
 
@@ -755,6 +765,19 @@ def cluster_access():
     pass
 
 
+def cluster_access_check_environment(env: Environment):
+    try:
+        registry_url = get_registry_url(env.config)
+        cluster_metadata = registry.get_cluster_with_params(registry_url, api_server_url=get_api_server_url(env.config))
+        if cluster_metadata["environment"] == "test":
+            raise ClusterAccessUnsupported("Cluster access requests are not needed in test clusters")
+    except ClusterAccessUnsupported:
+        raise
+    except Exception as e:
+        # We don't want to prevent the users from using these commands if CR is down
+        clickclick.warning("Unable to verify cluster environment: {}".format(e))
+
+
 @cluster_access.command("request")
 @click.option("--emergency", is_flag=True, help="Request emergency access to the cluster")
 @click.option("-i", "--incident", help="Incident number, required with --emergency", type=str)
@@ -763,6 +786,8 @@ def cluster_access():
 @click.pass_obj
 def request_cluster_access(env: Environment, emergency, incident, user, reason):
     """Request access to the cluster"""
+    cluster_access_check_environment(env)
+
     if emergency:
         if not incident:
             raise click.UsageError("You must specify an incident ticket [--incident] when requesting emergency access")
@@ -775,23 +800,6 @@ def request_cluster_access(env: Environment, emergency, incident, user, reason):
         make_manual_access_request(env.config, user, reason)
 
 
-@click_cli.command("emergency-access")
-@click.option("-i", "--incident", help="Incident number", required=True, type=str)
-@click.option("-u", "--user", help="User that should be given access, defaults to the current user", required=False)
-@click.argument("reason", nargs=-1, required=True)
-@click.pass_context
-def request_emergency_access(ctx, incident, user, reason):
-    """
-    DEPRECATED - please use 'cluster-access'.
-
-    DEPRECATED in favor of 'zkubectl cluster-access request --emergency'
-
-    Request 24x7 access to the cluster
-    """
-    clickclick.warning("DEPRECATED in favor of 'zkubectl cluster-access request --emergency'")
-    ctx.invoke(request_cluster_access, emergency=True, incident=incident, user=user, reason=reason)
-
-
 def make_emergency_access_request(config, incident, user, reason):
     user = access_request_username(user)
     reference_url = "https://techjira.zalando.net/browse/INC-{}".format(incident) if incident else None
@@ -802,20 +810,6 @@ def make_emergency_access_request(config, incident, user, reason):
     )
 
 
-@click_cli.command("manual-access")
-@click.argument("reason", nargs=-1, required=True)
-@click.pass_context
-def request_manual_access(ctx, reason):
-    """
-    DEPRECATED - please use 'cluster-access'.
-
-    DEPRECATED in favor of 'zkubectl cluster-access request'
-
-    Request manual access to the cluster"""
-    clickclick.warning("DEPRECATED in favor of 'zkubectl cluster-access request'")
-    ctx.invoke(request_cluster_access, emergency=False, incident=None, user=None, reason=reason)
-
-
 def make_manual_access_request(config, user_option, reason):
     user = access_request_username(user_option)
     access_request.create(config, "manual", None, user, " ".join(reason))
@@ -823,8 +817,9 @@ def make_manual_access_request(config, user_option, reason):
     click.echo("You can ask your colleague to approve it using these commands:\n")
     current_cluster = kube_config.get_current_context()
     if current_cluster:
-        click.echo("    zkubectl login {}".format(current_cluster))
-    click.echo("    zkubectl cluster-access approve {}\n".format(user))
+        click.echo("zkubectl login {} && zkubectl cluster-access approve {}\n".format(current_cluster, user))
+    else:
+        click.echo("zkubectl cluster-access approve {}\n".format(user))
 
 
 @cluster_access.command("approve")
@@ -832,6 +827,8 @@ def make_manual_access_request(config, user_option, reason):
 @click.pass_obj
 def approve_access_request(env: Environment, username):
     """Approve a manual access request"""
+    cluster_access_check_environment(env)
+
     if not username:
         username = click.prompt("User that should receive access")
 
@@ -847,25 +844,12 @@ def approve_access_request(env: Environment, username):
             click.echo("Approved access for user {user}: {reason}".format(user=username, reason=updated_reason))
 
 
-@click_cli.command("approve-manual-access")
-@click.argument("username", required=True)
-@click.pass_context
-def approve_manual_access(ctx, username):
-    """
-    DEPRECATED - please use 'cluster-access'.
-
-    DEPRECATED in favor of 'zkubectl cluster-access approve'
-
-    Approve a manual access request
-    """
-    clickclick.warning("DEPRECATED in favor of 'zkubectl cluster-access approve'")
-    ctx.forward(approve_access_request)
-
-
 @cluster_access.command("list")
 @click.pass_obj
 def list_cluster_requests(env: Environment):
     """List all current pending/approved access requests for the cluster"""
+    cluster_access_check_environment(env)
+
     all_requests = access_request.get_all(env.config)
     access_requests = sorted(all_requests.values(), key=lambda r: r["user"])
 
@@ -889,20 +873,6 @@ def list_cluster_requests(env: Environment):
     )
 
 
-@click_cli.command("list-access-requests")
-@click.pass_context
-def list_access_requests(ctx):
-    """
-    DEPRECATED - please use 'cluster-access'.
-
-    DEPRECATED in favor of 'zkubectl cluster-access list'
-
-    List all current pending/approved access requests for the cluster
-    """
-    clickclick.warning("DEPRECATED in favor of 'zkubectl cluster-access list'")
-    ctx.forward(list_cluster_requests)
-
-
 @click_cli.command("restart-pods", help="Restart all pods in a deployment.")
 @click.argument("target")
 @click.pass_obj
@@ -993,3 +963,4 @@ def main():
         sys.exit(141)
     except Exception as e:
         clickclick.error(e)
+        sys.exit(1)
