@@ -23,3 +23,8 @@ class IngressTemplate(BlueGreen):
 
         if len(self.stacks) == 1 and weight not in (0, 100):
             raise ValueError("Backend {} is the only one; weight must be either 0 or 100.".format(stack_name))
+
+        if self.get_traffic_complement(stack_name) == 0 and len(self.stacks) != 1:
+            raise ValueError(
+                "All stacks other than {} have no weight. Please choose a different one.".format(stack_name)
+            )
